@@ -1,10 +1,11 @@
+import os
 from os import sep
 from glob import glob
 import pandas as pd
 import numpy as np
 # from tqdm import tqdm
-from datetime import timedelta
-from microt_compliance_matrix.utils.validate_date import *
+from datetime import datetime, timedelta
+from microt_compliance_matrix import utils
 
 
 target_file_pattern = 'phone_app_usage_clean*.csv'
@@ -45,7 +46,7 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
 
 def combine_intermediate_file(intermediate_participant_path, date_in_study):
     df_logs_combined = pd.DataFrame()
-    participant_id = extract_participant_id(intermediate_participant_path)
+    participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
 
     # generate date range where date folder exists (sharable code in utils)
     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
